package dev.fitko.fitconnect.core.http;

import org.springframework.http.HttpInputMessage;
import org.springframework.http.HttpOutputMessage;
import org.springframework.http.MediaType;
import org.springframework.http.converter.AbstractHttpMessageConverter;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.http.converter.HttpMessageNotWritableException;
import org.springframework.lang.NonNull;

import java.security.cert.CertificateFactory;
import java.security.cert.X509CRL;

public class X509CRLHttpMessageConverter extends AbstractHttpMessageConverter<X509CRL> {

    public X509CRLHttpMessageConverter() {
        super(new MediaType("application", "pkix-crl"));
    }

    @Override
    protected boolean supports(@NonNull final Class<?> clazz) {
        return X509CRL.class == clazz;
    }

    @Override
    protected X509CRL readInternal(@NonNull final Class<? extends X509CRL> clazz, @NonNull final HttpInputMessage inputMessage)
            throws HttpMessageNotReadableException {
        try {
            final var cf = CertificateFactory.getInstance("X.509");
            return (X509CRL) cf.generateCRL(inputMessage.getBody());
        } catch (final Exception e) {
            throw new HttpMessageNotReadableException("CertificateFactory of type X.509 could not be created", inputMessage);
        }
    }

    @Override
    protected void writeInternal(@NonNull final X509CRL x509CRL, @NonNull final HttpOutputMessage outputMessage)
            throws HttpMessageNotWritableException {
        throw new HttpMessageNotWritableException("Writing X509CRL is not supported in ProxyRestTemplate");
    }

}
