package dev.fitko.fitconnect.core;

import com.github.tomakehurst.wiremock.WireMockServer;
import com.github.tomakehurst.wiremock.client.WireMock;
import dev.fitko.fitconnect.api.config.ApplicationConfig;
import dev.fitko.fitconnect.api.config.Environment;
import dev.fitko.fitconnect.api.config.EnvironmentName;
import dev.fitko.fitconnect.api.config.ResourcePaths;

import java.util.Map;

import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.wireMockConfig;

public abstract class RestEndpointBase {

    public static WireMockServer wireMockServer;

    static {
        wireMockServer = new WireMockServer(wireMockConfig().dynamicPort());
        wireMockServer.start();
        WireMock.configureFor("localhost", wireMockServer.port());
    }

    protected ApplicationConfig getTestConfig(final String fakeBaseUrl) {

        final var envName = new EnvironmentName("TESTING");
        final var environments = Map.of(envName, new Environment(fakeBaseUrl, fakeBaseUrl, false));

        final var resourcePaths = ResourcePaths.builder()
                .authTokenPath("/token")
                .destinationPath("/v1/destinations/{destinationId}")
                .destinationKeyPath("/v1/destinations/{destinationId}/keys/{kid}")
                .eventLogPath("/v1/cases/{caseId}/events")
                .submissionsPath("/v1/submissions")
                .submissionPath("/v1/submissions/{submissionId}")
                .submissionAttachmentPath("/v1/submissions/{submissionId}/attachments/{attachmentId}")
                .build();

        return ApplicationConfig.builder()
                .environments(environments)
                .activeEnvironment(envName)
                .resourcePaths(resourcePaths)
                .build();
    }

}
