package dev.fitko.fitconnect.core.http;

import org.junit.jupiter.api.Test;
import org.springframework.http.client.InterceptingClientHttpRequestFactory;
import org.springframework.web.client.RestTemplate;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.jupiter.api.Assertions.*;

class ProxyConfigTest {

    ProxyConfig underTest;

    @Test
    void proxyRestTemplate() {
        // Given
        underTest = new ProxyConfig("http://testhost.de", 8080);

        // When
        final RestTemplate template = underTest.proxyRestTemplate();

        // Then
        assertNotNull(template);
        assertThat(template.getRequestFactory().getClass(), equalTo(InterceptingClientHttpRequestFactory.class));

    }

    @Test
    void hasProxySet() {
        // Given
        underTest = new ProxyConfig("http://testhost.de", 8080);

        // When
        final boolean proxySet = underTest.hasProxySet();

        // Then
        assertTrue(proxySet);
    }

    @Test
    void hasProxyNotSet() {
        // Given
        underTest = new ProxyConfig(null, 0);

        // When
        final boolean proxySet = underTest.hasProxySet();

        // Then
        assertFalse(proxySet);
    }

    @Test
    void testToString() {
        // Given
        underTest = new ProxyConfig("http://testhost.de", 8080);

        // When
        final String configAsString = underTest.toString();

        // Then
        assertEquals("ProxyConfig {host='http://testhost.de', port=8080}", configAsString);
    }
}